@@ -5,6 +5,10 @@ import time
 
 def progressbar(iterable, log=None):
     """
+    Args:
+        iterable
+        log (logger): optional
+
     Examples:
         >>> import logging
         >>> import rna
@@ -21,13 +25,16 @@ def progressbar(iterable, log=None):
         log = logging.getLogger()
     try:
         from tqdm import tqdm as progressor
+
         tqdm_exists = True
     except ImportError:
+
         def progressor(iterable):
             """
             dummy function. Doe nothing
             """
             return iterable
+
         tqdm_exists = False
     try:
         nTotal = len(iterable)
@@ -44,9 +51,10 @@ def progressbar(iterable, log=None):
 
 
 @contextmanager
-def timeit(msg="No Description", log=None, precision=1):
+def timeit(msg="No Description", log=None, precision=1) -> None:
     """
     Context manager for autmated timeing
+
     Args:
         msg (str): message to customize the log message
         log (logger)
@@ -61,12 +69,17 @@ def timeit(msg="No Description", log=None, precision=1):
 
     yield
 
-    log.log(logging.INFO, "\t\t\t\t\t\t<- Process Duration:"
-            "{value:1.{precision}f} s".format(value=time.time() - startTime,
-                                              precision=precision))
+    log.log(
+        logging.INFO,
+        "\t\t\t\t\t\t<- Process Duration:"
+        "{value:1.{precision}f} s".format(
+            value=time.time() - startTime, precision=precision
+        ),
+    )
     log.log(logging.INFO, "<- " * 30)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import doctest
+
     doctest.testmod()
